#include "circbuf.h"


/* 
 * Implementation of a circular buffer. There is no handling of
 * race conditions, for example two independent write operations
 * would lead to an undefined state. As long as one process only
 * reads and one process only writes data from or to the buffer,
 * this implementation is safe. For initialization a variable of
 * type TCircBuf must be defined with an appropriate sized buffer
 * array.
 */
  
   char circbuf_get(struct circular_buffer *buf) {
	char ret = buf->data[buf->tail];
    buf->tail++;
    buf->fillcount--;
    return(ret);
  }
  
  void circbuf_add(struct circular_buffer *buf, char value) {
	buf->data[buf->head] = value;
    buf->head++;
    buf->fillcount++;
  }
  
  bool circbuf_isempty(struct circular_buffer *buf) {
    if (buf->fillcount == 0) return true;
    else return false;
  }
  
  bool circbuf_isfull(struct circular_buffer *buf) {
    if (buf->fillcount == buf->size) return true;
    else return false;
  }
  
  void circbuf_clear(struct circular_buffer *buf){
	  buf->head =0;
	  buf->tail =0;
  }
